@@ -8,11 +8,11 @@
 #' separated by an underscore. They follow the format of \code{service_whatitdoes}.
 #' For example, \code{gnr_resolve} uses the Global Names Resolver API to resolve
 #' species names.
-#' 
+#'
 #' General functions in the package that don't hit a specific API don't have
 #' two words separated by an underscore, e.g., \code{classification}
 #'
-#' You need API keys for Encyclopedia of Life (EOL), the Universal Biological 
+#' You need API keys for Encyclopedia of Life (EOL), the Universal Biological
 #' Indexer and Organizer (uBio), Tropicos, and Plantminer.
 #'
 #' Currently supported APIs are:
@@ -38,12 +38,12 @@
 #' Barcode of Life Data Systems (BOLD) \tab bold \tab FALSE \cr
 #' Pan-European Species directories Infrastructure (PESI) \tab pesi \tab TRUE \cr
 #' Mycobank \tab myco \tab TRUE \cr
+#' National Biodiversity Network (UK)	\tab nbn \tab FALSE \cr
 #' }
-#' 
-#' If the source above has a \code{TRUE} in the \code{SOAP?} column, it is not available if you 
-#' installed this package from CRAN. See the Github repo for how to install the version with the 
-#' data sources that use SOAP web services: 
-#' \url{https://github.com/ropensci/taxize#version-with-soap-data-sources}
+#'
+#' If the source above has a \code{TRUE} in the \code{SOAP?} column, it is not available if you
+#' installed this package from CRAN. They are available from a different package called taxizesoap.
+#' See the Github repo for how to install \url{https://github.com/ropensci/taxizesoap}
 #'
 #' @name taxize-package
 #' @aliases taxize
@@ -51,11 +51,11 @@
 #' @title Taxonomic information from around the web.
 #' @author Scott Chamberlain \email{myrmecocystus@@gmail.com}
 #' @author Eduard Szoecs \email{eduardszoecs@@gmail.com}
+#' @author Zachary Foster \email{zacharyfoster1989@@gmail.com}
 #' @author Carl Boettiger \email{cboettig@@gmail.com}
 #' @author Karthik Ram \email{karthik@@ropensci.org}
 #' @author Ignasi Bartomeus \email{nacho.bartomeus@@gmail.com}
 #' @author John Baumgartner \email{johnbb@@student.unimelb.edu.au}
-
 #' @keywords package
 NULL
 
@@ -103,29 +103,44 @@ NULL
 
 #' Deprecated functions in taxize
 #'
-#' The following functions are now deprecated - see the function \code{classification}
+#' The following functions are now deprecated:
 #'
 #' \itemize{
-#'  \item \code{\link{col_classification}}: This function is deprecated. See \code{classification}
-#'  \item \code{\link{eol_hierarchy}}: This function is deprecated. See \code{classification}
-#'  \item \code{\link{tp_classification}}: This function is deprecated. See \code{classification}
+#'  \item \code{\link{ncbi_getbyname}}: This function is deprecated and will be removed in a future
+#'  version of this package.
+#'  \item \code{\link{ncbi_getbyid}}: This function is deprecated and will be removed in a future
+#'  version of this package.
+#'  \item \code{\link{ncbi_search}}: This function is deprecated and will be removed in a future
+#'  version of this package.
+#'  \item \code{\link{phylomatic_tree}}: This function is deprecated and will be removed in a future
+#'  version of this package.
+#'  \item \code{\link{eol_invasive}}: This function is deprecated and will be removed in a future
+#'  version of this package.
+#'  \item \code{\link{gisd_isinvasive}}: This function is deprecated and will be removed in a future
+#'  version of this package.
 #' }
 #'
-#' The following functions have changed names. The old function names are still available to call,
-#' but simply return a message directing the user to the new function name.
-#'
-#' \itemize{
-#'  \item \code{\link{get_seqs}}: This function has changed name to \code{ncbi_getbyname}.
-#'  \item \code{\link{get_genes}}: This function has changed name to \code{ncbi_getbyid}.
-#'  \item \code{\link{get_genes_avail}}: This function has changed name to \code{ncbi_search}.
-#'  \item \code{\link{tp_acceptednames}}: This function has changed name to \code{tp_accnames}.
-#'  \item \code{\link{tp_namedistributions}}: This function has changed name to \code{tp_dist}.
-#'  \item \code{\link{tp_namereferences}}: This function has changed name to \code{tp_refs}.
-#'  \item \code{\link{itis_name}}: This function has changed name to \code{tax_name}.
-#' }
-#'
-#' In addition, \code{tpl_search} is deprecated - use the Taxonstand functions \code{TPL} or
-#' \code{TPLck} directly.
+#' All of the above functions will be available in an R package in development called traits
+#' \url{https://github.com/ropensci/traits} that will be available on CRAN before these functions
+#' are made defunct here.
 #'
 #' @name taxize-deprecated
 NULL
+
+#' Defunct functions in taxize
+#'
+#' The following functions are now defunct (no longer available):
+#'
+#' \itemize{
+#'  \item \code{\link{col_classification}}: See \code{\link{classification}}
+#'  \item \code{\link{eol_hierarchy}}: See \code{\link{classification}}
+#'  \item \code{\link{tp_classification}}: See \code{\link{classification}}
+#'  \item \code{\link{tpl_search}}: Use the \code{Taxonstand} functions
+#'  \code{\link[Taxonstand]{TPL}} or \code{\link[Taxonstand]{TPLck}} directly.
+#'  \item \code{\link{get_seqs}}: This function changed name to \code{\link{ncbi_getbyname}}.
+#'  \item \code{\link{get_genes}}: This function changed name to \code{\link{ncbi_getbyid}}.
+#'  \item \code{\link{get_genes_avail}}: This function changed name to \code{\link{ncbi_search}}.
+#' }
+#'
+#' @name taxize-defunct
+NULL
