@@ -8,7 +8,7 @@ temp2 <- comm2sci(commnames='black bear', db='tropicos')
 temp3 <- comm2sci(commnames=c('black bear','roe deer'), db='eol')
 
 test_that("comm2sci returns the correct value", {
-  expect_that(names(tt), equals('black bear'))  
+  expect_that(names(tt), equals('black bear'))
   expect_that(names(uu), equals('annual blue grass'))
   expect_identical(comm2sci(commnames='bear', db='itis', itisby = "asfasdf")[[1]], character(0))
   expect_named(temp2)
@@ -23,6 +23,6 @@ test_that("comm2sci returns the correct class", {
   expect_is(comm2sci(commnames='black bear', db='itis', simplify = FALSE)[[1]], "data.frame")
 })
 
-test_that("errors when expected", {
-  expect_error(comm2sci(commnames='', db='eol'))
-})
\ No newline at end of file
+# test_that("errors when expected", {
+#   expect_error(comm2sci(commnames='', db='eol'))
+# })
