@@ -2,7 +2,7 @@
 context("gisd_isinvasive")
 
 sp <- c("Carpobrotus edulis", "Rosmarinus officinalis")
-out <- gisd_isinvasive(sp, simplify = TRUE, verbose=FALSE)
+out <- suppressWarnings(gisd_isinvasive(sp, simplify = TRUE, verbose=FALSE))
 
 test_that("gisd_isinvasive returns the correct value", {
 	expect_that(dim(out), equals(c(2,2)))
